@@ -10,7 +10,7 @@
 ** implied warranty.
  */
 
-/* $Id: libpnmrw.c,v 1.8 1998/06/09 21:08:57 torsten Exp $ */
+/* $Id: libpnmrw.c,v 1.9 2000/10/02 20:53:00 torsten Exp $ */
 
 #if defined(HAVE_PARAM_H)
 #include <sys/param.h>
@@ -46,7 +46,7 @@
 
 void *malloc(int);
 void free(void *);
-#if defined(__EMX__) || defined(__CYGWIN32__)
+#if defined(__EMX__) || defined(__CYGWIN__)
 #include <errno.h>
 #endif
 
@@ -135,10 +135,16 @@ pm_perror(char *reason)
     __const extern char *__const sys_errlist[];
 #else
 #ifndef __GLIBC__
-    extern char *sys_errlist[];
+#ifndef SYS_ERRLIST_DEFINED
+#ifdef __CYGWIN__
+#  define sys_errlist _sys_errlist
+#else
+   extern char *sys_errlist[]
 #endif
 #endif
-#if !defined(__EMX__) || defined(__CYGWIN32__)
+#endif
+#endif
+#if !defined(__EMX__) || defined(__CYGWIN__)
     extern int errno;
 #endif
     char *e;
