@@ -12,11 +12,14 @@
 /* |								       | */
 /* +-------------------------------------------------------------------+ */
 
-/* $Id: writeTIFF.c,v 1.5 1996/05/28 09:19:16 torsten Exp $ */
+/* $Id: writeTIFF.c,v 1.6 2000/09/02 08:38:46 torsten Exp $ */
 
 #include <stdio.h>
 #include <stdlib.h>
 #include <tiffio.h>
+
+#include <X11/Intrinsic.h>
+#include "xpaint.h"
 #include "image.h"
 
 #undef howmany
@@ -41,14 +44,19 @@ int WriteTIFF(char *file, Image * image)
 	    buf = (unsigned char *) malloc(sizeof(char) * image->width / 8 + 4);
     } else {
 	Image *cmapImage;   /* GRR 960525 */
+        int depth = 
+              DefaultDepth(Global.display, DefaultScreen(Global.display));
 
-	/* try compressing image to a colormap, but don't force compression */
-	if (!image->maskData)   /* can TIFF store alpha channel with palette? */
-	    cmapImage = ImageCompress(image, 256, 1);
-	if (cmapImage)
-	    image = cmapImage;  /* original was deleted in ImageCompress() */
+        if (depth <= 8) {
+  	      /* try compressing image to a colormap, but don't force it */
+	  if (!image->maskData)   
+              /* can TIFF store alpha channel with palette? */
+	      cmapImage = ImageCompress(image, 256, 1);
+	  if (cmapImage)
+	      image = cmapImage;  /* original was deleted in ImageCompress() */
+	}
 
-	if (image->cmapSize == 0 || image->cmapSize > 256) {
+	if (depth > 8 || image->cmapSize == 0 || image->cmapSize > 256) {
 	    photometric = PHOTOMETRIC_RGB;
 	    samplesPP = 3;
 	    bitsPP = 8;
@@ -57,8 +65,10 @@ int WriteTIFF(char *file, Image * image)
 	    samplesPP = 1;
 	    bitsPP = 8;
 	}
+
     }
 
+
     if ((out = TIFFOpen(file, "w")) == NULL)
 	return 1;
 
